# -*- coding: utf-8 -*-
"""
    avrsim
    ~~~~~~

    MyHDL simulator for AVR chips
"""

__all__ = (
    "__title__","__version__","__url__","__summary__",
    "__author__","__email__","__license__","__copyright__",
)

__title__   =   "AVRsim"
__version__ =   "0.1.0"
__url__     =   "https://github.com/rblack42/avrsim"
__summary__ =   "An MyHDL simulator for AVR chips"
__author__  =   "Roie R. Black"
__email__   =   "rblack@austincc.edu"
__license__ =   "BSD 3-Clause"
__copyright__   = "Copyright 2016 Roie R. Black"



import unittest

class TestSanity(unittest.TestCase):

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def test_sanity(self):
        self.assertEqual(1, 1)

if __name__ == '__main__':
    unittest.main()



from setuptools import setup, find_packages
import avrsim

setup(
    name = avrsim.__name__,
    version = avrsim.__version__,
    description = avrsim.__summary__,
    url = avrsim.__url__,
    author = avrsim.__author__,
    author_email = avrsim.__email__,
    packages = find_packages(),
    include_package_data = True,
    zip_safe = False,
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.5',
        'Natural Language :: English',
        'Intended Audience :: Developers',
        'Intended Audience :: Education',
        'Intended Audience :: Science/Research',
    ]
)
